@@ -15,9 +15,11 @@
 from __future__ import print_function
 
 import datetime
+import grp
 import json
 import logging
 import os
+import pwd
 import signal
 import subprocess
 import tempfile
@@ -112,34 +114,34 @@ class HeatBaseLauncher(object):
     # and chown them accordingly for the heat user
     def __init__(self, api_port, container_image, user='heat'):
         self.api_port = api_port
-        tmpdir = '/var/tmp/undercloud'
+        heatdir = '/var/log/heat-launcher'
 
-        if os.path.isdir(tmpdir):
+        if os.path.isdir(heatdir):
             # This one may fail but it's just cleanup.
-            p = subprocess.Popen(['umount', tmpdir],
+            p = subprocess.Popen(['umount', heatdir],
                                  stdout=subprocess.PIPE,
                                  stderr=subprocess.PIPE)
             cmd_stdout, cmd_stderr = p.communicate()
             retval = p.returncode
             if retval != 0:
                 log.info('Cleanup unmount of %s failed (probably because '
-                         'it was not mounted): %s' % (tmpdir, cmd_stderr))
+                         'it was not mounted): %s' % (heatdir, cmd_stderr))
             else:
-                log.info('umount of %s success' % (tmpdir))
+                log.info('umount of %s success' % (heatdir))
         else:
             # Create the directory if it doesn't exist.
             try:
-                os.makedirs(tmpdir, mode=0o755)
+                os.makedirs(heatdir, mode=0o700)
             except Exception as e:
                 log.error('Creating temp directory "%s" failed: %s' %
-                          (tmpdir, e))
+                          (heatdir, e))
                 raise Exception('Could not create temp directory %s: %s' %
-                                (tmpdir, e))
+                                (heatdir, e))
         # As an optimization we mount the tmp directory in a tmpfs (in memory)
         # filesystem.  Depending on your system this can cut the heat
         # deployment times by half.
         p = subprocess.Popen(['mount', '-t', 'tmpfs', '-o', 'size=500M',
-                              'tmpfs', tmpdir],
+                              'tmpfs', heatdir],
                              stdout=subprocess.PIPE,
                              stderr=subprocess.PIPE)
         cmd_stdout, cmd_stderr = p.communicate()
@@ -148,12 +150,12 @@ class HeatBaseLauncher(object):
             # It's ok if this fails, it will still work.  It just won't
             # be on tmpfs.
             log.warning('Unable to mount tmpfs for logs and database %s: %s' %
-                        (tmpdir, cmd_stderr))
+                        (heatdir, cmd_stderr))
 
         self.policy_file = os.path.join(os.path.dirname(__file__),
                                         'noauth_policy.json')
         self.install_tmp = tempfile.mkdtemp(prefix='%s/undercloud_deploy-' %
-                                            tmpdir)
+                                            heatdir)
         self.container_image = container_image
         self.user = user
         self.sql_db = os.path.join(self.install_tmp, 'heat.sqlite')
@@ -182,7 +184,7 @@ rpc_poll_timeout = 60
 rpc_response_timeout = 600
 deferred_auth_method = password
 num_engine_workers=1
-convergence_engine = false
+convergence_engine = true
 max_json_body_size = 8388608
 heat_metadata_server_url=http://127.0.0.1:%(api_port)s/
 default_deployment_signal_transport = HEAT_SIGNAL
@@ -268,28 +270,26 @@ class HeatDockerLauncher(HeatBaseLauncher):
         cmd = [
             'docker', 'run', '--rm',
             self.container_image,
-            'getent', 'passwd'
+            'getent', 'passwd', self.user
         ]
         log.debug(' '.join(cmd))
         p = subprocess.Popen(cmd, stdout=subprocess.PIPE)
         result = p.communicate()[0]
-        for line in result.split("\n"):
-            if line.startswith('%s:' % self.user):
-                return line.split(':')[2]
+        if result:
+            return result.split(':')[2]
         raise Exception('Could not find heat uid')
 
     def get_heat_gid(self):
         cmd = [
             'docker', 'run', '--rm',
             self.container_image,
-            'getent', 'group'
+            'getent', 'group', self.user
         ]
         log.debug(' '.join(cmd))
         p = subprocess.Popen(cmd, stdout=subprocess.PIPE)
         result = p.communicate()[0]
-        for line in result.split("\n"):
-            if line.startswith('%s:' % self.user):
-                return line.split(':')[2]
+        if result:
+            return result.split(':')[2]
         raise Exception('Could not find heat gid')
 
     def kill_heat(self, pid):
@@ -313,14 +313,10 @@ class HeatNativeLauncher(HeatBaseLauncher):
                                self.config_file, 'db_sync'])
 
     def get_heat_uid(self):
-        p = subprocess.Popen(["getent", "passwd", "|", "grep", "heat"],
-                             stdout=subprocess.PIPE)
-        return p.communicate()[0].rstrip().split(':')[2]
+        return pwd.getpwnam('heat').pw_uid
 
     def get_heat_gid(self):
-        p = subprocess.Popen(["getent", "group", "|", "grep", "heat"],
-                             stdout=subprocess.PIPE)
-        return p.communicate()[0].rstrip().split(':')[2]
+        return grp.getgrnam('heat').gr_gid
 
     def kill_heat(self, pid):
         os.kill(pid, signal.SIGKILL)
