@@ -20,7 +20,6 @@ import logging
 import netaddr
 import os
 import shutil
-import yaml
 
 from cryptography import x509
 
@@ -427,23 +426,21 @@ def prepare_undercloud_deploy(upgrade=False, no_validations=False,
         env_data['BarbicanSimpleCryptoGlobalDefault'] = True
         env_data['SwiftEncryptionEnabled'] = True
 
-    if CONF.get('generate_service_certificate'):
-        deploy_args += ['-e', os.path.join(
-            tht_templates,
-            "environments/public-tls-undercloud.yaml")]
-    elif CONF.get('undercloud_service_certificate'):
-        enable_tls_yaml_path = os.path.join(tht_templates,
-                                            "environments/ssl/enable-tls.yaml")
+    if CONF.get('undercloud_service_certificate'):
+        # We assume that the certificate is trusted
+        env_data['InternalTLSCAFile'] = ''
         env_data.update(
             _get_public_tls_parameters(
                 CONF.get('undercloud_service_certificate')))
-        registry_overwrites.update(
-            _get_public_tls_resource_registry_overwrites(enable_tls_yaml_path))
         deploy_args += [
             '-e', os.path.join(tht_templates, 'environments/services/'
                                'undercloud-haproxy.yaml'),
             '-e', os.path.join(tht_templates, 'environments/services/'
                                'undercloud-keepalived.yaml')]
+    elif CONF.get('generate_service_certificate'):
+        deploy_args += ['-e', os.path.join(
+            tht_templates,
+            "environments/public-tls-undercloud.yaml")]
     else:
         deploy_args += ['-e', os.path.join(
             tht_templates,
@@ -561,7 +558,7 @@ def prepare_undercloud_deploy(upgrade=False, no_validations=False,
         deploy_args += ['--hieradata-override=%s' % data_file]
 
     if CONF.get('enable_validations') and not no_validations:
-        undercloud_preflight.check(verbose_level)
+        undercloud_preflight.check(verbose_level, upgrade)
         deploy_args += ['-e', os.path.join(
             tht_templates, "environments/tripleo-validations.yaml")]
 
@@ -628,18 +625,6 @@ def _get_public_tls_parameters(service_certificate_path):
         }
 
 
-def _get_public_tls_resource_registry_overwrites(enable_tls_yaml_path):
-    with open(enable_tls_yaml_path, 'rb') as enable_tls_file:
-        enable_tls_dict = yaml.load(enable_tls_file.read())
-        try:
-            return enable_tls_dict['resource_registry']
-        except KeyError:
-            msg = _('%s is malformed and is missing the resource '
-                    'registry.') % enable_tls_yaml_path
-            LOG.error(msg)
-            raise RuntimeError(msg)
-
-
 def _container_images_config(conf, deploy_args, env_data, tempdir):
     if conf.container_images_file:
         deploy_args += ['-e', conf.container_images_file]
